<?php
/**
 * Moony - the PHP simplistic framework
 *
 * @package   Moony
 * @author    YAMAOKA Hiroyuki <yamaoka@catwalker.jp>
 * @link      http://moony.sourceforge.jp/
 * @copyright 2005-2007 YAMAOKA Hiroyuki
 * @license   http://opensource.org/licenses/bsd-license.php The BSD License
 */

/**
 * 別のテンプレートファイルを読み込んで表示するヘルパー関数です。
 * 該当のテンプレートファイルが存在しない場合、何も処理しません。
 * PHPテンプレートの内部で使用されます。
 * （例: <?php moony_include('foo.php'); ?>）
 *
 * @access public
 * @param string $template テンプレートファイル
 */
function moony_include($template)
{
    $action =& Moony_Registry::get('_moony_action');
    $result = $action->fetch($template);
    if ($result !== false) {
        print($result);
    }
}

/**
 * 全ての検証エラーメッセージを表示するヘルパー関数です。
 * エラーメッセージが設定されていない場合、何も処理しません。
 * PHPテンプレートの内部で使用されます。
 * （例: <?php moony_errors(); ?>）
 *
 * @access public
 * @param string $header 全体のヘッダ
 * @param string $footer 全体のフッタ
 * @param string $prefix 個々のメッセージの接頭辞
 * @param string $postfix 個々のメッセージの接尾辞
 */
function moony_errors(
    $header = '<ul>', $footer = '</ul>',
    $prefix = '<li>', $postfix = '</li>')
{
    $errors = Moony_Registry::get('_moony_errors');
    if (count($errors) > 0) {
        print($header);
        foreach ($errors as $error) {
            print($prefix . $error . $postfix);
        }
        print($footer . "\n");
    }
}

/**
 * 検証エラーの有無を判断するヘルパー関数です。
 * PHPテンプレートの内部で使用されます。
 * （例: <?php if (moony_has_error()): ?>）
 *
 * @access public
 * @return bool 検証エラーの存在有無
 */
function moony_has_error()
{
    $has_error = Moony_Registry::get('_moony_has_error');
    if (!is_null($has_error)) {
        return $has_error;
    }
    return false;
}

/**
 * ワンタイムトークンを埋め込んだ
 * hiddenフィールドを埋め込むヘルパー関数です。
 * PHPテンプレートの内部で使用されます。
 * （例: <?php moony_token(); ?>）
 *
 * @access public
 * @param bool $is_xhtml XHTMLとして埋め込むかどうか
 */
function moony_token($is_xhtml = true)
{
    $action =& Moony_Registry::get('_moony_action');
    $token = md5(uniqid(rand(), true));
    $action->session->set('_moony_token', $token);
    $html = '<input type="hidden" name="_moony_token" value="'
          . $token
          . ($is_xhtml ? '" />' : '">') . "\n";
    print($html);
}

/**
 * 文字列を出力用にエスケープするヘルパー関数です。
 * PHPテンプレートの内部で使用されます。
 * （例: <?php h($this->foo); ?>）
 * $echoがtrueの場合、エスケープ結果は出力されます。
 * $echoがfalseの場合、エスケープ結果は戻り値として返されます。
 *
 * @access public
 * @param string $str エスケープ対象の文字列
 * @param bool $echo エスケープ結果を出力するかどうか
 * @return null|string $echoがtrueの場合、エスケープ結果
 */
function h($str, $echo = true)
{
    $str = htmlspecialchars($str, ENT_QUOTES);
    if ($echo) {
        print($str);
    } else {
        return $str;
    }
}
?>
