<?php
class Moony_FilterTest extends UnitTestCase
{
    var $f;

    function setUp()
    {
        $this->f = new Moony_Filter('UTF-8');
    }

    function testFilterAlpha1()
    {
        $str = 'at63njd9823jer';
        $this->f->filterAlpha($str);
        $this->assertEqual('atnjdjer', $str);
    }

    function testFilterAlpha2()
    {
        $var = array('at63njd9823jer', 'sdfd834this22e7');
        $this->f->filterAlpha($var);
        $this->assertEqual(array('atnjdjer', 'sdfdthise'), $var);
    }

    function testFilterAlnum1()
    {
        $str = '#>>at63n`@jd9$8%23jer';
        $this->f->filterAlnum($str);
        $this->assertEqual('at63njd9823jer', $str);
    }

    function testFilterAlnum2()
    {
        $var = array('#>>at63n`@jd9$8%23jer', 'ewkgfpop##"#E3e2');
        $this->f->filterAlnum($var);
        $this->assertEqual(array('at63njd9823jer', 'ewkgfpopE3e2'), $var);
    }

    function testFilterDigit1()
    {
        $str = '#>>at63n`@jd9$8%23jer';
        $this->f->filterDigit($str);
        $this->assertEqual('639823', $str);
    }

    function testFilterDigit2()
    {
        $var = array('#>>at63n`@jd9$8%23jer', 'ewkgfpop##"#E3e2');
        $this->f->filterDigit($var);
        $this->assertEqual(array('639823', '32'), $var);
    }

    function testFilterPattern1()
    {
        $str = '#>>at69993n`@jd9$8%23jer';
        $this->f->filterPattern($str, '/[^0-5a-z]/');
        $this->assertEqual('at3njd23jer', $str);
    }

    function testFilterPattern2()
    {
        $var = array('#>>at69993n`@jd9$8%23jer', '5433-0oi9u989f');
        $this->f->filterPattern($var, '/[^0-5a-z]/');
        $this->assertEqual(array('at3njd23jer', '54330oiuf'), $var);
    }

    function testToInt1()
    {
        $val = 123.435545;
        $this->f->toInt($val);
        $this->assertEqual(123, $val);
    }

    function testToInt2()
    {
        $var = array(123.546, 453.65432);
        $this->f->toInt($var);
        $this->assertEqual(array(123, 453), $var);
    }

    function testToLowercase1()
    {
        $val = 'aaAaaA';
        $this->f->toLowercase($val);
        $this->assertEqual('aaaaaa', $val);
    }

    function testToLowercase2()
    {
        $var = array('ytyuRHsrGEy', 'ygk64sDAEr3DsdSD');
        $this->f->toLowercase($var);
        $this->assertEqual(array('ytyurhsrgey', 'ygk64sdaer3dsdsd'), $var);
    }

    function testToUppercase1()
    {
        $val = 'aaAaaA';
        $this->f->toUppercase($val);
        $this->assertEqual('AAAAAA', $val);
    }

    function testToUppercase2()
    {
        $var = array('ytyuRHsrGEy', 'ygk64sDAEr3DsdSD');
        $this->f->toUppercase($var);
        $this->assertEqual(array('YTYURHSRGEY', 'YGK64SDAER3DSDSD'), $var);
    }

    function testToHiragana1()
    {
        $val = 'あアｱァあ';
        $this->f->toHiragana($val);
        $this->assertEqual('あああぁあ', $val);
    }

    function testToHiragana2()
    {
        $var = array('イテスタてしはファ', 'ｳﾃｽていしいﾃｼﾀ');
        $this->f->toHiragana($var);
        $this->assertEqual(array('いてすたてしはふぁ', 'うてすていしいてした'), $var);
    }

    function testToKatakana1()
    {
        $val = 'あアｱァあ';
        $this->f->toKatakana($val);
        $this->assertEqual('アアアァア', $val);
    }

    function testToKatakana2()
    {
        $var = array('イテスタてしはフぁ', 'ｳﾃｽていしいﾃｼﾀ');
        $this->f->toKatakana($var);
        $this->assertEqual(array('イテスタテシハファ', 'ウテステイシイテシタ'), $var);
    }

    function testToKana1()
    {
        // @TODO
    }

    function testToKana2()
    {
    }

    function testToBaseName1()
    {
        $str = '/usr/local/foo/bar/sample.txt';
        $this->f->toBaseName($str);
        $this->assertEqual('sample.txt', $str);
    }

    function testToBaseName2()
    {
        $var = array('/usr/local/bar.html', 'C:\yayaya\test.txt');
        $this->f->toBaseName($var);
        $this->assertEqual(array('bar.html', 'test.txt'), $var);
    }

    function testToHtmlEntities1()
    {
        $str = '<>,\'#*"';
        $this->f->toHtmlEntities($str);
        $this->assertEqual('&lt;&gt;,\'#*&quot;', $str);
        $str = '<>,\'#*"';
        $this->f->toHtmlEntities($str, ENT_QUOTES);
        $this->assertEqual('&lt;&gt;,&#039;#*&quot;', $str);
    }

    function testToHtmlEntities2()
    {
    }

    function testTrim1()
    {
        $str = " abc\n";
        $this->f->trim($str);
        $this->assertEqual('abc', $str);
        $str = 'abc';
        $this->f->trim($str, 'ac');
        $this->assertEqual('b', $str);
    }

    function testTrim2()
    {
        $var = array(' abc ', "def\n");
        $this->f->trim($var);
        $this->assertEqual(array('abc', 'def'), $var);
        $var = array('abcd', 'sdfdc');
        $this->f->trim($var, 'acd');
        $this->assertEqual(array('b', 'sdf'), $var);
    }

    function testLtrim1()
    {
        $str = " abc\n";
        $this->f->ltrim($str);
        $this->assertEqual("abc\n", $str);
        $str = 'abcd';
        $this->f->ltrim($str, 'ab');
        $this->assertEqual('cd', $str);
    }

    function testLtrim2()
    {
        $var = array("\tabc", "\nds");
        $this->f->ltrim($var);
        $this->assertEqual(array('abc', 'ds'), $var);
        $var = array('abc', 'aaads');
        $this->f->ltrim($var, 'a');
        $this->assertEqual(array('bc', 'ds'), $var);
    }

    function testRtrim1()
    {
        $str = " abc\n";
        $this->f->rtrim($str);
        $this->assertEqual(' abc', $str);
    }

    function testRtrim2()
    {
    }
}
?>
